SystemOrganization addCategory: #ConfigurationOfCommonTraits!

Object subclass: #ConfigurationOfCommonTraits
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCommonTraits'!

!ConfigurationOfCommonTraits class methodsFor: 'private' stamp: 'SantiagoBragagnolo 9/13/2012 12:01'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfCommonTraits class methodsFor: 'private' stamp: 'SantiagoBragagnolo 9/13/2012 12:01'!
ensureMetacello
	"Bootstrap Gofer (if necessary), load latest mcz file for ConfigurationOfMetacello (using old 
	 Gofer API), then load the latest version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [ | error |
		"list of repositories to try, in case primary repository is not accessible"
		(Array 
			with: 'http://www.squeaksource.com/MetacelloRepository' 
			with: 'http://seaside.gemstone.com/ss/metacello') do: [:repositoryUrl |
				([
					Smalltalk at: #Gofer ifAbsent: [
					"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
						self bootstrapPackage: 'Gofer-Core-lr.115' from: repositoryUrl ].
					Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
						gofer := goferClass new
							url: repositoryUrl;
							yourself.
						[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
						gofer load ]]
							on: Error
							do: [ :ex |
								error := ex.
								Transcript 
									cr; 
									show: 'failed ensureMetacello: ';
									show: ex description printString;
									show: '...retrying'.
								"try again"
								ex return: nil ]) ~~ nil
					ifTrue: [
						"load 'default' group of Metacello"
						(Smalltalk at: #ConfigurationOfMetacello) perform: #load.
						^self ]].
		"shouldn't get here unless the load failed ... throw an error"
		self error: 'retry with alternate repository failed: ', error description printString ]! !

!ConfigurationOfCommonTraits class methodsFor: 'metacello tool support' stamp: 'SantiagoBragagnolo 9/13/2012 11:59'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCommonTraits class methodsFor: 'metacello tool support' stamp: 'SantiagoBragagnolo 9/13/2012 11:59'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfCommonTraits class methodsFor: 'loading' stamp: 'SantiagoBragagnolo 9/13/2012 11:58'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfCommonTraits class methodsFor: 'metacello tool support' stamp: 'SantiagoBragagnolo 9/13/2012 12:00'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfCommonTraits class methodsFor: 'accessing' stamp: 'SantiagoBragagnolo 9/13/2012 11:57'!
project

	^self new project! !

!ConfigurationOfCommonTraits class methodsFor: 'unloading metacello' stamp: 'SantiagoBragagnolo 9/13/2012 12:00'!
unloadMetacello

	Smalltalk at: #ConfigurationOfMetacello ifPresent: [:cls | cls unloadMetacello ]! !

!ConfigurationOfCommonTraits methodsFor: 'as yet unclassified' stamp: 'SantiagoBragagnolo 9/13/2012 12:42'!
baseline10: spec
	<version:'1.0-baseline'>
	spec for: #common do: [
			spec blessing: #baseline.
			spec repository: 'http://ss3.gemstone.com/ss/CommonTraits'.
			spec project: 'CommonTraits'.
			spec package: 'CommonTraits'.
	].
! !

!ConfigurationOfCommonTraits methodsFor: 'as yet unclassified' stamp: 'SantiagoBragagnolo 9/13/2012 11:39'!
project

	^ project ifNil: [
		 | constructor |
		
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project 
	].! !
